California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 83 - SEX OFFENDERS. SEXUALLY VIOLENT PREDATORS. PUNISHMENT, RESIDENCE RESTRICTIONS AND MONITORING. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1279632 | SOUTHERN CALIFORNIANS FOR JESSICA'S LAW - COMMITTEE FOR PROPOSITION 83 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1277423 | CAMPAIGN FOR CHILD SAFETY 2006 - JESSICA'S LAW, YES ON 83 | SUPPORT